
<p align="center">  
  
  <a href="#">
    <img src="https://github.com/ChinaIceF/PyQt-SiliconUI/blob/main/assets/readme/silicon_main.png?raw=true" alt="Logo"  >
  </a>
  
  <h2 align="center">PyQt-SiliconUI</h2>
  <p align="center">A powerful and artistic UI library based on PyQt5</p>

<p align="center">
    English | <a href="docs/README_zh.md">简体中文</a>
</p>

## Install
Download this repository and run setup.py in cmd line:
```cmd
python setup.py install
```
Due to the fact that this project is still in the development stage, it is temporarily not available on PyPi.

However, we are currently working hard on it and will be available soon.


## Run Examples
Run `examples/Gallery for siui/start.py` to take a look at widgets and components of PyQt-SiliconUI

To quick start, run:
```cmd
cd "examples/Gallery for siui"
start start.py
```
Other more detailed examples for widgets are coming soon.


## See Also
Here are some project that created based on PyQt-SiliconUI:
* [My-TODOs](https://github.com/ChinaIceF/My-TODOs) - A cross-platform desktop To-Do list.


## License
PyQt-SiliconUI is licensed under [GPLv3](LICENSE) 

Copyright © 2024 by ChinaIceF.